@@ -17,7 +17,7 @@ our @EXPORT_OK = qw(
     );
 our @EXPORT = @EXPORT_OK;
 
-our $VERSION=q{3.2.15};
+our $VERSION=q{3.2.16};
 
 our @MANIFEST = (
 'clear.sh',
@@ -599,6 +599,14 @@ my %parse_options_low_level_make_sandbox = (
                                             'does not modify server UUID in MySQL 5.6+',
                                          ],
                             },
+    keep_auth_plugin        => {
+                                value => $ENV{KEEP_AUTH_PLUGIN} || $ENV{keep_auth_plugin} || 0, 
+                                parse => 'keep_auth_plugin',
+                                so    => 315,
+                                help  => [
+                                            'In MySQL 8.0.4+, does not change the default authentication plugin',
+                                         ],
+                            },
     history_dir             => {
                                 value => $ENV{HISTORY_DIR} || $ENV{HISTORYDIR} || '', 
                                 parse => 'history_dir=s',
@@ -2538,7 +2546,7 @@ ADD_OPTION
 
 my $license_text = <<'LICENSE';
 #    The MySQL Sandbox
-#    Copyright (C) 2006-2017 Giuseppe Maxia
+#    Copyright (C) 2006-2018 Giuseppe Maxia
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -2686,13 +2694,13 @@ For a reference manual, see L<MySQL::Sandbox>. For a cookbook, see L<MySQL::Sand
 
 Version 3.1
 
-Copyright (C) 2006-2017 Giuseppe Maxia
+Copyright (C) 2006-2018 Giuseppe Maxia
 
 Home Page  https://github.com/datacharmer
 
 =head1 LEGAL NOTICE
 
-   Copyright 2006-2017 Giuseppe Maxia
+   Copyright 2006-2018 Giuseppe Maxia
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
